
From: Kumar Gala <galak@somerset.sps.mot.com>

Fixes up the reporting of the e500 core revision.  Additionally, it changes
the reporting of CPU frequency to match what other PPC systems do.

Signed-off-by: Kumar Gala <kumar.gala@freescale.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc/kernel/setup.c                      |    4 ++++
 25-akpm/arch/ppc/platforms/85xx/mpc85xx_ads_common.c |    3 +--
 25-akpm/arch/ppc/platforms/85xx/mpc85xx_cds_common.c |    3 +--
 25-akpm/arch/ppc/platforms/85xx/sbc85xx.c            |    3 +--
 4 files changed, 7 insertions(+), 6 deletions(-)

diff -puN arch/ppc/kernel/setup.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus arch/ppc/kernel/setup.c
--- 25/arch/ppc/kernel/setup.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus	2004-11-08 21:43:25.937348984 -0800
+++ 25-akpm/arch/ppc/kernel/setup.c	2004-11-08 21:43:25.944347920 -0800
@@ -226,6 +226,10 @@ int show_cpuinfo(struct seq_file *m, voi
 		maj = ((pvr >> 8) & 0xFF) - 1;
 		min = pvr & 0xFF;
 		break;
+	case 0x8020:	/* e500 */
+		maj = PVR_MAJ(pvr);
+		min = PVR_MIN(pvr);
+		break;
 	default:
 		maj = (pvr >> 8) & 0xFF;
 		min = pvr & 0xFF;
diff -puN arch/ppc/platforms/85xx/mpc85xx_ads_common.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus arch/ppc/platforms/85xx/mpc85xx_ads_common.c
--- 25/arch/ppc/platforms/85xx/mpc85xx_ads_common.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus	2004-11-08 21:43:25.938348832 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/mpc85xx_ads_common.c	2004-11-08 21:43:25.945347768 -0800
@@ -142,8 +142,7 @@ mpc85xx_ads_show_cpuinfo(struct seq_file
 		seq_printf(m, "Machine\t\t: unknown\n");
 		break;
 	}
-	seq_printf(m, "bus freq\t: %u.%.6u MHz\n", freq / 1000000,
-		   freq % 1000000);
+	seq_printf(m, "clock\t\t: %dMHz\n", freq / 1000000);
 	seq_printf(m, "PVR\t\t: 0x%x\n", pvid);
 	seq_printf(m, "SVR\t\t: 0x%x\n", svid);
 
diff -puN arch/ppc/platforms/85xx/mpc85xx_cds_common.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus arch/ppc/platforms/85xx/mpc85xx_cds_common.c
--- 25/arch/ppc/platforms/85xx/mpc85xx_cds_common.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus	2004-11-08 21:43:25.940348528 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/mpc85xx_cds_common.c	2004-11-08 21:43:25.945347768 -0800
@@ -172,8 +172,7 @@ mpc85xx_cds_show_cpuinfo(struct seq_file
 
         seq_printf(m, "Vendor\t\t: Freescale Semiconductor\n");
 	seq_printf(m, "Machine\t\t: CDS (%x)\n", cadmus[CM_VER]);
-        seq_printf(m, "bus freq\t: %u.%.6u MHz\n", freq / 1000000,
-                   freq % 1000000);
+	seq_printf(m, "clock\t\t: %dMHz\n", freq / 1000000);
         seq_printf(m, "PVR\t\t: 0x%x\n", pvid);
         seq_printf(m, "SVR\t\t: 0x%x\n", svid);
 
diff -puN arch/ppc/platforms/85xx/sbc85xx.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus arch/ppc/platforms/85xx/sbc85xx.c
--- 25/arch/ppc/platforms/85xx/sbc85xx.c~ppc32-updated-reporting-of-cpu-rev-freq-for-e500-cpus	2004-11-08 21:43:25.941348376 -0800
+++ 25-akpm/arch/ppc/platforms/85xx/sbc85xx.c	2004-11-08 21:43:25.946347616 -0800
@@ -142,8 +142,7 @@ sbc8560_show_cpuinfo(struct seq_file *m)
 		seq_printf(m, "Machine\t\t: unknown\n");
 		break;
 	}
-	seq_printf(m, "bus freq\t: %u.%.6u MHz\n", freq / 1000000,
-		   freq % 1000000);
+	seq_printf(m, "clock\t\t: %dMHz\n", freq / 1000000);
 	seq_printf(m, "PVR\t\t: 0x%x\n", pvid);
 	seq_printf(m, "SVR\t\t: 0x%x\n", svid);
 
_
